@@ -10,7 +10,7 @@ use Carp;
 use Class::Trigger;
 use UNIVERSAL::require;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 our $AUTOLOAD;
 our $cache_status = {
     retrieve_count => 0,
@@ -158,7 +158,7 @@ sub primary_keys {
 
 sub unique_keys {
     my $class = shift;
-    $class->schema->primary_keys;
+    $class->schema->unique_keys;
 }
 
 sub columns {
@@ -166,6 +166,13 @@ sub columns {
     $class->schema->columns;
 }
 
+sub has_column {
+    my $class = shift;
+    my $col = shift or return;
+    $class->columns or return;
+    grep { $col eq $_ } @{$class->columns};
+}
+
 # oid, db, create, retrieve..
 sub object_id {
     my $self = shift;
@@ -477,7 +484,7 @@ sub _retrieve_by_or_create_handler {
         my $self = shift;
         my %args;
         @args{@keys} = @_;
-        $self->retrieve(%args) || $class->create(%args);
+        return $self->retrieve(%args) || $class->create(%args);
     };
 }
 
@@ -748,6 +755,10 @@ Returns DBIx::MoCo::Schema object reference related with your model class.
 
 =item columns
 
+=item has_column(col_name)
+
+Returns which the table has the column or not.
+
 =item retrieve
 
 =item retrieve_or_create
